# delimit;
clear;
set mem 20m;
cd  "F:\Projects\Josh";  
log using table10_9gr_MEN_farc94.log, replace;

use data_urban_alt;
keep if age <=23 & sex!=3;
keep if year<=2000;
sort year dep_ocu age sex urban;
save one, replace;

use pop_sex;
keep if year<=2000 & year>=1992;
sort year dep_ocu age sex;
save pop, replace;

use one;
merge year dep_ocu age sex using pop;

if population!=0 {
  replace death=0 if death==.;
  replace violent_a=0 if violent_a==.;
  replace disease=0 if disease==.;
  replace homicide=0 if homicide==.;
  replace accident=0 if accident==.;
};

gen newage=(age-7)*5;

***keep only males aged 15-59, according to the SAS file - double check the age filter here!;
keep if newage>=15 & newage<=60;
keep if sex==1;

replace newage=15 if newage==20;
replace newage=25 if newage==30;
replace newage=35 if newage==40;
replace newage=45 if newage==50;
replace newage=55 if newage==60;


******************************************
***generate growing department definitions
***NOTE: uncomment line at end if you want a 14 dept. definition of growing rather than a 9 dept.;

gen grow94=1 if 
	dep_ocu==13 |
  	dep_ocu==18 |
	dep_ocu==19 |
	dep_ocu==50 |
	dep_ocu==52 |
	dep_ocu==86 |
	dep_ocu==95 |
	dep_ocu==97 |
	dep_ocu==99;
replace grow94=0 if grow94==.;

gen plante94=1 if 
	grow94==1 |
	dep_ocu==20 |
	dep_ocu==54 |
	dep_ocu==94;
replace plante94=0 if plante94==.;

gen plante94p=1 if
	plante94==1 |
	dep_ocu==44 |
	dep_ocu==47;
replace plante94p=0 if plante94p==.;

*** (*) LINE BELOW FOR FOR 9 DEPT. EXCLUDING THE 5 DEPT. (14-9);
drop if dep_ocu==20 | dep_ocu==44 | dep_ocu==47 | dep_ocu==54 | dep_ocu==94;
tab dep_ocu;


gen DMZ=1 if
	dep_ocu==50 |
	dep_ocu==18;
replace DMZ=0 if DMZ==.;

gen prov_type="Non-growing" if grow94==0;
replace prov_type="Growing" if grow94==1;
replace prov_type="DMZ" if grow94==1 & DMZ==1;
drop _merge;
save temp, replace;

***the following creates dept_cat, a set linking dept. numbers with growing and DMZ status, and prov_type;
keep dep_ocu DMZ grow94;
collapse grow94 DMZ, by(dep_ocu);
gen prov_type="Non-growing" if grow94==0;
replace prov_type="Growing" if grow94==1;
replace prov_type="DMZ" if grow==1 & DMZ==1;

sort dep_ocu;
save dept_cat, replace;
**************************************************;


********************************************************
****collapsing to sum across groups and categories******;
use temp;
collapse (sum) death violent_a accident disease homicide population, by(urban year dep_ocu newage);
sort dep_ocu ;
save temp1, replace;

******because the variable violent has missing values for some year/department/age combinations, to be consistent with
******the way SAS handles missing values in a sum, I collapse 'violent' separately and merge it back in;
******I suspect 'violent' may still not be handled the way it is in the sas file, but it appears irrelevant to the
******subsequent analysis, so I'm leaving it as is;

use temp;
collapse (sum) violent if violent!=., by(year dep_ocu newage);
sort year dep_ocu newage ;
save temp2, replace;

use temp1;
merge dep_ocu using dept_cat;
drop _merge;
sort year dep_ocu newage ;
merge year dep_ocu newage using temp2;
drop _merge; 
sort dep_ocu;
save temp3, replace;

use newvars2;
merge dep_ocu using temp3;
drop _merge;
********************************************************;

********************************************************;
gen arate=100000*(accident/population);
gen vrate=100000*(violent_a/population);
gen drate=100000*(disease/population);
gen hrate=100000*(homicide/population);

gen lnvrate=log(violent_a/population) if violent_a>0;
gen lnvratio=log(violent_a/(death-violent_a)) if violent_a>0 & violent_a<death;
gen lndrate=log(disease/population) if disease>0;
gen post=1 if year>=1995;
replace post=0 if year<1995;

*** POOLED YEAR DUMMIES ***;
gen d94=1 if year==1994;
replace d94=0 if d94==.;
gen d9597=1 if year<=1997 & year>=1995;
replace d9597=0 if d9597==.;
gen d9800=1 if year<=2000 & year>=1998;
replace d9800=0 if d9800==.;
*** END POOLED YEAR DUMMIES ***;

gen negyear94=-year if year>=1994;
replace negyear94=0 if year<1994;

gen negyear93=-year if year>=1993;
replace negyear93=0 if year<1993;

gen growing=1 if prov_type=="Growing";
replace growing=0 if growing==.;

gen trend=year-1989;



gen bigcity=1 if
	dep_ocu==5 |
	dep_ocu==11 |
	dep_ocu==76;
replace bigcity=0 if bigcity==.;


keep if bigcity==0;

gen clusterid=dep_ocu;

label variable lnvratio "logit violent death rate";
label variable vrate "violent death rate";
label variable drate "disease death rate";
label variable DMZ "Meta or Cauqeta";

**************************************************
****     Generate all the dummy variables     ****;

***interaction variables***;
gen growing_negyear93=growing*negyear93;
gen DMZ_negyear93=DMZ*negyear93;
gen growing_negyear94=growing*negyear94;
gen DMZ_negyear94=DMZ*negyear94;

*** POOLED INTERACTIONS ***;
gen growing_94=growing*d94;
gen DMZ_94=DMZ*d94;
gen growing_9597=growing*d9597;
gen DMZ_9597=DMZ*d9597;
gen growing_9800=growing*d9800;
gen DMZ_9800=DMZ*d9800;
*** END OF POOLED INTERACTIONS ***;

***year, department, age dummies***;
separate year, by(year);
separate dep_ocu, by(dep_ocu);
separate newage, by(newage);
drop year2000 newage55 dep_ocu99;
recode year1992-newage45 (nonmiss=1) (missing=0);

***transform interaction variables into a set of dummies***;
local i=1993;
while `i'<=2000 {;
gen growing_negyear93_`i'=1 if growing_negyear93==-`i';
replace growing_negyear93_`i'=0 if growing_negyear93_`i'==.;

gen DMZ_negyear93_`i'=1 if DMZ_negyear93==-`i';
replace DMZ_negyear93_`i'=0 if DMZ_negyear93_`i'==.;
local i=`i'+1;
};

local j=1994;
while `j'<=2000 {;
gen growing_negyear94_`j'=1 if growing_negyear94==-`j';
replace growing_negyear94_`j'=0 if growing_negyear94_`j'==.;

gen DMZ_negyear94_`j'=1 if DMZ_negyear94==-`j';
replace DMZ_negyear94_`j'=0 if DMZ_negyear94_`j'==.;
local j=`j'+1;
};

***generate trend terms***;
gen growing_trend=trend if prov_type=="Growing";
gen non_growing_trend=trend if prov_type=="Non-growing";
gen DMZ_trend=trend if prov_type=="DMZ";
recode growing_trend-DMZ_trend (missing=0);

keep if urban!=.;

***Note that the st. errors for the regressions are slightly different than those reported in the paper, 
***since SAS and Stata must calculate st. errors differently when clustering;

***Note: paper reports unweighted results in Table 4, but weighted results are provided below as well;

gen d1993_growing=year1993*growing;
gen d1994_growing=year1994*growing;
gen d1993_DMZ=year1993*DMZ;
gen d1994_DMZ=year1994*DMZ;

*** NEW INTERACTIONS ***;
gen growing_DMZ=0;
replace growing_DMZ=1 if growing==1 | DMZ==1;
gen growing_DMZ_94=growing_DMZ*d94;
gen growing_DMZ_9597=growing_DMZ*d9597;
gen growing_DMZ_9800=growing_DMZ*d9800;

gen farc94_1=0; replace farc94_1=1 if farc94==1;
gen farc94_0=0; replace farc94_0=1 if farc94==0;
gen growing_DMZ_94_farc94_1=growing_DMZ_94*farc94_1;
gen growing_DMZ_94_farc94_0=growing_DMZ_94*farc94_0;
gen growing_DMZ_9597_farc94_1=growing_DMZ_9597*farc94_1;
gen growing_DMZ_9597_farc94_0=growing_DMZ_9597*farc94_0;
gen growing_DMZ_9800_farc94_1=growing_DMZ_9800*farc94_1;
gen growing_DMZ_9800_farc94_0=growing_DMZ_9800*farc94_0;
gen growing_DMZ_trend=0; replace growing_DMZ_trend=trend if growing==1 | DMZ==1;

gen farc94_growing_DMZ=farc94*growing_DMZ;
gen farc94_d94=farc94*d94;
gen farc94_d9597=farc94*d9597;
gen farc94_d9800=farc94*d9800;
************************;

**************************************************;
*****            data summary                *****;
**************************************************;
sort urban;
by urban: summarize;

**************************************************;
*****empirical model - no trends             *****;
**************************************************;
***rural***;
reg lnvrate dep_ocu8-dep_ocu97 year1992-year1999 newage15-newage45 farc94 farc94_growing_DMZ farc94_d94 farc94_d9597 farc94_d9800 growing_DMZ_94_farc94_1 growing_DMZ_94_farc94_0 growing_DMZ_9597_farc94_1 growing_DMZ_9597_farc94_0 growing_DMZ_9800_farc94_1 growing_DMZ_9800_farc94_0 if urban==0, cluster(clusterid);

**************************************************;
*****empirical model - w/trends              *****;
**************************************************;
***rural***;
reg lnvrate dep_ocu8-dep_ocu97 year1992-year1999 newage15-newage45 farc94 farc94_growing_DMZ farc94_d94 farc94_d9597 farc94_d9800 growing_DMZ_94_farc94_1 growing_DMZ_94_farc94_0 growing_DMZ_9597_farc94_1 growing_DMZ_9597_farc94_0 growing_DMZ_9800_farc94_1 growing_DMZ_9800_farc94_0 growing_DMZ_trend if urban==0, cluster(clusterid);

erase one.dta;
erase pop.dta;
erase temp.dta;
erase temp1.dta;
erase temp2.dta;
erase temp3.dta;
erase dept_cat.dta;

log close;
